@@ -1,6 +1,6 @@
 package Games::Bingo::Column;
 
-# $Id: Column.pm,v 1.11 2003/07/30 17:53:11 jonasbn Exp $
+# $Id: Column.pm,v 1.12 2003/12/27 10:27:16 jonasbn Exp $
 
 use strict;
 use integer;
@@ -9,7 +9,7 @@ use Games::Bingo;
 use vars qw(@ISA $VERSION);
 
 @ISA = qw(Games::Bingo);
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 sub new {
 	my $class = shift;
@@ -32,12 +32,6 @@ sub populate {
 	@{$self->{_array}} = sort _reverse @{$self->{_array}};
 }
 
-sub set_status {
-	my ($self, $status) = @_;
-
-	$self->{_status} = $status;
-}
-
 sub get_random_number {
 	my ($self, $do_splice) = @_;
 	
@@ -58,12 +52,19 @@ sub count_numbers {
 	return $count;
 }
 
-sub get_number {
-	my $self = shift;
+sub get_highest_number {
+	my ($self, $do_splice) = @_;
 
-	my $number = shift(@{$self->{_array}});
-
-	return $number;
+	my $number;
+	if ($do_splice) {
+		$number = shift(@{$self->{_array}});
+		return $number;
+	} else {
+		for (my $i = scalar @{$self->{_array}}; $i >= 0; $i--) {
+			$number = ${$self->{_array}}[$i];
+			return $number if $number =~ m/^\d+$/;
+		}
+	}
 }
 
 1;
@@ -89,9 +90,7 @@ C<< my @numbers = qw(1 2 3 4 5 6 7 8 9); >>
 
 C<< my $c = Games::Bingo::Column-E<gt>new(@numbers); >>
 
-C<< my $number = $c-E<gt>get_number(1); >>
-
-C<< my $c-E<gt>set_status(1); >>
+C<< my $number = $c-E<gt>get_highest_number(); >>
 
 =cut
 
@@ -113,11 +112,9 @@ actually is nothing but an array with a status flag.
 
 =item *
 
-_status 
+label
 
-The status attribute is a flag indicating whether the collection has
-been used during the generation of bingo cards, please refer to the
-accessor set_status for more information.
+The label being the group to which the numbers in the array belong.
 
 =back
 
@@ -132,27 +129,29 @@ B<_array> attribute to point to this.
 
 =head2 populate
 
-populate is a simple accessor which can be used to add additional number
+B<populate> is a simple accessor which can be used to add additional number
 to the list of number contained in the class. This is a secondary use of
 the class, please refer to the description of the algoritms used in the
 program described in the Games::Bingo class.
 
-=head2 set_status
+=head2 get_highest_number
 
-This accessor method can be used to set the status of the Column, the
-attribute B<_status>. The values used to indicate whether the column has
-been used is B<1> for true and B<0> for false. Meaning B<0> is the
-default value and the value of a new Column.
-
-=head2 get_number
-
-The get_number is also a simple accessor, it return a random number from
-the list contained in the class.
+The B<get_highest_number> is also a simple accessor, it returns the
+highest number from the list contained in the class.
 
 If the optional parameter is set to true, it splices the list contained
 in the class, meaning the class shrinks by B<1>. Default behaviour is
 not shrinking.
 
+=head2 get_random_number
+
+The B<get_random__number> is also a simple accessor, it returns a
+random number from the list contained in the class.
+
+If the optional parameter is set to true, it splices the list contained
+in the class, meaning the class shrinks by B<1>. Default behaviour is
+not shrinking. See also B<get_highest_number>.
+
 =head2 _reverse
 
 The method used by Perls sort to sort the list
